# LiveCut
# (c) 2002 Jerome Alet <alet@librelogiciel.com>
# You're welcome to redistribute this software under the
# terms of the GNU General Public Licence version 2.0
# or, at your option, any higher version.
#
# You can read the complete GNU GPL in the file COPYING
# which should come along with this software, or visit
# the Free Software Foundation's WEB site http://www.fsf.org
#
# $Id: MainFrame.py,v 1.5 2003/02/27 13:15:40 jalet Exp $
#
#

from wxPython.wx import *

import TimeLine

def create(parent, file):
    return MainFrame(parent, file)

[wxID_MAINFRAME, wxID_MAINFRAMEMAINBOX, wxID_MAINFRAMESLIDE_BUTTON, wxID_MAINFRAMEMAIN, wxID_MAINFRAMEQUIT_BUTTON, wxID_MAINFRAMESKIP_BUTTON, wxID_MAINFRAMESTART_BUTTON, wxID_MAINFRAMESPEAKER_BUTTON] = map(lambda _init_ctrls: wxNewId(), range(8))

[wxID_MAINFRAMECHRONO] = map(lambda _init_utils: wxNewId(), range(1))

class MainFrame(wxFrame):
    def _init_utils(self):
        self.chrono = wxTimer(evtHandler = self, id = wxID_MAINFRAMECHRONO)
        EVT_TIMER(self, wxID_MAINFRAMECHRONO, self.OnChronoTimer)

    def _init_ctrls(self, prnt):
        wxFrame.__init__(self, id = wxID_MAINFRAME, name = '', parent = prnt, pos = wxPoint(315, 217), size = wxSize(382, 317), style = wxDEFAULT_FRAME_STYLE, title = 'LiveCut')
        self._init_utils()
        self.SetToolTipString('LiveCut timeline editor')
        self.SetClientSize(wxSize(382, 317))

        self.Main = wxWindow(id = wxID_MAINFRAMEMAIN, name = 'Main', parent = self, pos = wxPoint(0, 0), size = wxSize(376, 312), style = 0)
        self.Main.SetHelpText(_('Main Window'))
        self.Main.SetLabel(_('Main Window'))
        self.Main.SetToolTipString(_('Main'))

        from livecut import __version__
        self.MainBox = wxStaticBox(id = wxID_MAINFRAMEMAINBOX, label = 'LiveCut v%s' % __version__, name = 'MainBox', parent = self.Main, pos = wxPoint(8, 0), size = wxSize(368, 312), style = 0)
        self.MainBox.SetAutoLayout(true)

        self.Quit_Button = wxButton(id = wxID_MAINFRAMEQUIT_BUTTON, label = _('Quit'), name = 'Quit_Button', parent = self.Main, pos = wxPoint(144, 216), size = wxSize(80, 26), style = 0)
        self.Quit_Button.SetHelpText(_('Exit application'))
        self.Quit_Button.SetToolTipString(_('Quits the program'))
        EVT_BUTTON(self.Quit_Button, wxID_MAINFRAMEQUIT_BUTTON, self.OnQuit_buttonButton)

        self.Start_Button = wxToggleButton(id = wxID_MAINFRAMESTART_BUTTON, label = _('Start'), name = 'Start_Button', parent = self.Main, pos = wxPoint(104, 56), size = wxSize(96, 26), style = 0)
        self.Start_Button.SetToolTipString(_('Start recording'))
        self.Start_Button.SetHelpText(_('Start or Stop recording'))
        self.Start_Button.SetValue(false)
        EVT_TOGGLEBUTTON(self.Start_Button, wxID_MAINFRAMESTART_BUTTON, self.OnToggleStart_buttonTogglebutton)

        self.Speaker_Button = wxButton(id = wxID_MAINFRAMESPEAKER_BUTTON, label = _('Speaker'), name = 'Speaker_Button', parent = self.Main, pos = wxPoint(144, 120), size = wxSize(80, 26), style = 0)
        self.Speaker_Button.SetHelpText(_('Indicates a change to a new speaker'))
        self.Speaker_Button.SetToolTipString(_('Speaker change'))
        self.Speaker_Button.Enable(false)
        EVT_BUTTON(self.Speaker_Button, wxID_MAINFRAMESPEAKER_BUTTON, self.OnSpeaker_buttonButton)

        self.Slide_Button = wxButton(id = wxID_MAINFRAMESLIDE_BUTTON, label = _('Slide'), name = 'Slide_Button', parent = self.Main, pos = wxPoint(144, 160), size = wxSize(80, 26), style = 0)
        self.Slide_Button.SetHelpText(_('Indicates a change to a new slide'))
        self.Slide_Button.SetToolTipString(_('Slide change'))
        self.Slide_Button.Enable(false)
        EVT_BUTTON(self.Slide_Button, wxID_MAINFRAMESLIDE_BUTTON, self.OnSlide_buttonButton)

        self.Skip_Button = wxToggleButton(id = wxID_MAINFRAMESKIP_BUTTON, label = _('Skip'), name = 'Skip_Button', parent = self.Main, pos = wxPoint(144, 200), size = wxSize(80, 26), style = 0)
        self.Skip_Button.SetHelpText(_('Start or Stop skipping audio/video'))
        self.Skip_Button.SetToolTipString(_('Start skipping audio/video'))
        self.Skip_Button.Enable(false)
        EVT_TOGGLEBUTTON(self.Skip_Button, wxID_MAINFRAMESKIP_BUTTON, self.OnSkip_buttonButton)
        
        EVT_CLOSE(self, self.OnClose)
        
    def _init_sizers(self) :    
        self.MainBox.sizer = wxStaticBoxSizer(self.MainBox, wxVERTICAL)
        self.MainBox.sizer.Add(self.Start_Button, 1, wxEXPAND)
        self.MainBox.sizer.Add(self.Speaker_Button, 1, wxEXPAND)
        self.MainBox.sizer.Add(self.Slide_Button, 1, wxEXPAND)
        self.MainBox.sizer.Add(self.Skip_Button, 1, wxEXPAND)
        self.MainBox.sizer.Add(self.Quit_Button, 1, wxEXPAND)
        self.MainBox.SetAutoLayout(true)
        self.sizer = wxBoxSizer(wxBOTH)
        self.sizer.Add(self.MainBox.sizer, 0, wxEXPAND)
        self.SetSizer(self.sizer)
        self.SetAutoLayout(true)
        self.sizer.Fit(self)
        
    def __init__(self, parent, timeline):
        self._init_ctrls(parent)
        self._init_sizers()
        self.timeline = timeline
        self.TimeLine = None

    def OnClose(self, event) :
        if self.TimeLine is not None :
            self.TimeLine.cancel()
            self.TimeLine = None
        self.Destroy()    
        
    def OnQuit_buttonButton(self, event):
        if self.TimeLine is not None :
            self.TimeLine.stop()
            self.TimeLine = None
        self.Close(true)

    def OnToggleStart_buttonTogglebutton(self, event):
        if event.IsChecked() :
            self.Start_Button.SetToolTipString(_('Stop recording'))
            self.Start_Button.SetForegroundColour(wxColour(255, 0, 0))
            self.Start_Button.SetLabel(_('Stop'))
            self.Speaker_Button.Enable(true)
            self.Slide_Button.Enable(true)
            self.Skip_Button.Enable(true)
            self.TimeLine = TimeLine.TimeLine(self.timeline)
            self.TimeLine.start()
            self.chrono.Start(1000.0 / 25.0)       # 25 times per second
        else :
            self.chrono.Stop()
            self.TimeLine.stop()
            self.TimeLine = None
            self.Start_Button.SetToolTipString(_('Start recording'))
            self.Start_Button.SetForegroundColour(wxColour(0, 0, 0))
            self.Start_Button.SetLabel(_('Start'))
            self.Speaker_Button.Enable(false)
            self.Slide_Button.Enable(false)
            self.Skip_Button.Enable(false)
        
    def OnChronoTimer(self, event):
        try :
            self.Start_Button.SetLabel(self.TimeLine.getHMS())
        except AttributeError :    
            # too quick ! TimeLine already deleted
            pass

    def OnSpeaker_buttonButton(self, event):
        self.TimeLine.tick("Speaker")

    def OnSlide_buttonButton(self, event):
        self.TimeLine.tick("Slide")

    def OnSkip_buttonButton(self, event):
        if event.IsChecked() :    
            self.TimeLine.tick("SkipStart")
            self.Skip_Button.SetLabel(_("Skipping"))
            self.Skip_Button.SetToolTipString(_("Stop skipping audio/video"))
            self.Start_Button.Enable(false)
            self.Speaker_Button.Enable(false)
            self.Slide_Button.Enable(false)
            self.Quit_Button.Enable(false)
        else :
            self.TimeLine.tick("SkipStop")
            self.Skip_Button.SetLabel(_("Skip"))
            self.Skip_Button.SetToolTipString(_("Start skipping audio/video"))
            self.Start_Button.Enable(true)
            self.Speaker_Button.Enable(true)
            self.Slide_Button.Enable(true)
            self.Quit_Button.Enable(true)
