# LiveCut
# (c) 2002 Jerome Alet <alet@librelogiciel.com>
# You're welcome to redistribute this software under the
# terms of the GNU General Public Licence version 2.0
# or, at your option, any higher version.
#
# You can read the complete GNU GPL in the file COPYING
# which should come along with this software, or visit
# the Free Software Foundation's WEB site http://www.fsf.org
#
# $Id: TimeLine.py,v 1.5 2003/03/13 14:02:00 jalet Exp $
#
#

import os
import time

class TimeLine :
    """TimeLine class."""
    def __init__(self, file, dvcontrol=1) :
        """Initialize a timeline.
        
             file -- the file name or file objet to write the timeline to.
        """
        self.dvcontrol = dvcontrol
        self.file = file
        self._initialize()
        
    def _initialize(self) :    
        """Initialize the timeline."""
        self.begin = None
        self.events = []
        
    def _write(self) :
        """Writes the timeline to a file."""
        timeline = ''.join(["%s : %s%s\n" % (name, tick, (dvtc and " / ") and (" / " and dvtc)) for (name, tick, dvtc) in self.events])
        try :
            # first we try to use self.file as a file object
            self.file.write(timeline)
        except AttributeError :    
            # failure : probably a filename
            out = open(self.file, "w")
            out.write(timeline)
            out.close()
        
    #    
    # callable interface starts here    
    #
    def start(self) :
        """Starts the timeline."""
        if self.dvcontrol :
            os.system("dvcont record")
        self.begin = time.time()
        self.tick("Start")
        
    def stop(self) :
        """Ends the timeline and write it to a file."""
        self.tick("Stop")
        self._write()
        if self.dvcontrol :
            os.system("dvcont stop")
            os.system("dvcont eject")
        
    def cancel(self) :
        """Cancels the timeline."""
        self._initialize()
        
    def tick(self, event) :
        """Adds an event to the timeline.
        
             event -- the event name
        """
        self.events.append((event, self.getHMS(), self.getDVTimeCode()))
        
    def getDVTimeCode(self) :    
        """returns the DV TimeCode."""
        if self.dvcontrol :
            file = os.popen("dvcont timecode")
            timecode = file.read().strip()
            file.close()
            return timecode
        else :    
            return ""
        
    def getHMS(self) :
        """Returns duration as hh:mm:ss.cc in a string of text."""
        click = time.time() - self.begin
        hh = int(click / 3600)
        mm = int((click - (hh * 3600)) / 60)
        ssfloat = click % 60
        ss = int(ssfloat)
        cc = ssfloat - ss
        return "%02i:%02i:%02i.%02i" % (hh, mm, ss, int(cc * 100.0))
        
